==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/OperationFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { OperationFilterExpressionDescription } from "./OperationFilterExpressionDescription";
/**
 * @hidden
 */
export let OperationFilterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class OperationFilterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (OperationFilterExpressionDescriptionMetadata.a == null) {
                OperationFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OperationFilterExpressionDescriptionMetadata.c(OperationFilterExpressionDescriptionMetadata.a);
            }
            if (a.k(OperationFilterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(OperationFilterExpressionDescriptionMetadata.a);
            FilterExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("PropertyName", "String");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
            a.item("Left", "ExportedType:IFilterExpression");
            a.item("Right", "ExportedType:IFilterExpression");
            a.item("Operator", "ExportedType:string:FilterExpressionOperatorType");
            a.item("Operator@names", "None;Equal;NotEqual;GreaterThan;GreaterThanOrEqual;LessThan;LessThanOrEqual;And;Or;Not;Add;Subtract;Multiply;Divide;Modulo;Grouping");
        }
        static d(a) {
            OperationFilterExpressionDescriptionMetadata.b(a);
            a.ad("OperationFilterExpression", () => new OperationFilterExpressionDescription());
            a.ac("OperationFilterExpression", OperationFilterExpressionDescriptionMetadata.a);
        }
    }
    OperationFilterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(OperationFilterExpressionDescriptionMetadata, 'OperationFilterExpressionDescriptionMetadata');
    OperationFilterExpressionDescriptionMetadata.a = null;
    return OperationFilterExpressionDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/OperationFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { OperationFilterExpressionDescription } from "./OperationFilterExpressionDescription";
/**
 * @hidden
 */
export let OperationFilterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class OperationFilterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (OperationFilterExpressionDescriptionMetadata.a == null) {
                OperationFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OperationFilterExpressionDescriptionMetadata.c(OperationFilterExpressionDescriptionMetadata.a);
            }
            if (a.k(OperationFilterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(OperationFilterExpressionDescriptionMetadata.a);
            FilterExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("PropertyName", "String");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
            a.item("Left", "ExportedType:IFilterExpression");
            a.item("Right", "ExportedType:IFilterExpression");
            a.item("Operator", "ExportedType:string:FilterExpressionOperatorType");
            a.item("Operator@names", "None;Equal;NotEqual;GreaterThan;GreaterThanOrEqual;LessThan;LessThanOrEqual;And;Or;Not;Add;Subtract;Multiply;Divide;Modulo;Grouping");
        }
        static d(a) {
            OperationFilterExpressionDescriptionMetadata.b(a);
            a.ae("OperationFilterExpression", () => new OperationFilterExpressionDescription());
            a.ad("OperationFilterExpression", OperationFilterExpressionDescriptionMetadata.a);
        }
    }
    OperationFilterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(OperationFilterExpressionDescriptionMetadata, 'OperationFilterExpressionDescriptionMetadata');
    OperationFilterExpressionDescriptionMetadata.a = null;
    return OperationFilterExpressionDescriptionMetadata;
})();
